#
# This file adds a check for privileges used in the backup_security test.
# It is designed to attempt one of each type of command to ensure none of 
# these are enabled as a consequence of granting BACKUP or RESTORE to a 
# user who otherwise has no rights. 
#

--echo #
--echo # Show user has not gained rights.
--echo #

--echo #
--echo # Checking privileges for a table.
--echo #
--error ER_TABLEACCESS_DENIED_ERROR
SELECT * FROM backup_test.t1;
--error ER_TABLEACCESS_DENIED_ERROR
INSERT INTO backup_test.t1 VALUES ("900");
--error ER_TABLEACCESS_DENIED_ERROR
UPDATE backup_test.t1 SET a = "gotcha!";
--error ER_TABLEACCESS_DENIED_ERROR
DELETE FROM backup_test.t1;
--error ER_TABLEACCESS_DENIED_ERROR
TRUNCATE TABLE backup_test.t1;
--error ER_TABLEACCESS_DENIED_ERROR
ALTER TABLE backup_test.t1 ENGINE=MEMORY;
--error ER_TABLEACCESS_DENIED_ERROR
DROP TABLE backup_test.t1;
--error ER_TABLEACCESS_DENIED_ERROR
CREATE TABLE backup_test.t2 (a int);
--error ER_TABLEACCESS_DENIED_ERROR
DESCRIBE backup_test.t1;
--error ER_TABLEACCESS_DENIED_ERROR
SHOW CREATE TABLE backup_test.t1;

--echo #
--echo # Checking privileges for a view.
--echo #
--error ER_TABLEACCESS_DENIED_ERROR
SELECT * FROM backup_test.v1;
--error ER_TABLEACCESS_DENIED_ERROR
INSERT INTO backup_test.v1 VALUES ("800");
--error ER_TABLEACCESS_DENIED_ERROR
UPDATE backup_test.v1 SET a = "gotcha again!";
--error ER_TABLEACCESS_DENIED_ERROR
DELETE FROM backup_test.v1;
--error ER_TABLEACCESS_DENIED_ERROR
TRUNCATE TABLE backup_test.v1;
--error ER_TABLEACCESS_DENIED_ERROR
ALTER VIEW backup_test.v1 AS SELECT 1;
--error ER_TABLEACCESS_DENIED_ERROR
DROP VIEW backup_test.v1;
--error ER_TABLEACCESS_DENIED_ERROR
CREATE VIEW backup_test.v2 AS SELECT 0;
--error ER_TABLEACCESS_DENIED_ERROR
DESCRIBE backup_test.v1;
--error ER_TABLEACCESS_DENIED_ERROR
SHOW CREATE VIEW backup_test.v1;

--echo #
--echo # Checking privileges for a trigger.
--echo #
--error ER_TABLEACCESS_DENIED_ERROR
DROP TRIGGER backup_test.trg;
--error ER_TABLEACCESS_DENIED_ERROR
CREATE TRIGGER backup_test.trg2 BEFORE INSERT ON backup_test.t1 FOR EACH ROW
 INSERT INTO backup_test.t1 VALUES('not there at all');
#
# BUG#45412 : SHOW CREATE TRIGGER does not require privileges to disclose trigger data
#
#--error ER_TABLEACCESS_DENIED_ERROR
#SHOW CREATE TRIGGER backup_test.trg;

--echo #
--echo # Checking privileges for an event.
--echo #
--error ER_DBACCESS_DENIED_ERROR
DROP EVENT backup_test.e1;
--error ER_DBACCESS_DENIED_ERROR
ALTER EVENT backup_test.e1 ENABLE;
--error ER_DBACCESS_DENIED_ERROR
CREATE EVENT backup_test.e2 ON SCHEDULE EVERY 1 YEAR DO
  DELETE FROM backup_test.t1;
--error ER_DBACCESS_DENIED_ERROR
SHOW CREATE EVENT backup_test.e1;

--echo #
--echo # Checking privileges for a function.
--echo #
--error ER_PROCACCESS_DENIED_ERROR
DROP FUNCTION backup_test.f1;
--error ER_PROCACCESS_DENIED_ERROR
ALTER FUNCTION backup_test.f1 COMMENT "Tricky, eh?";
--error ER_DBACCESS_DENIED_ERROR
CREATE FUNCTION backup_test.f2() RETURNS INT RETURN (SELECT 11);
# Note: SHOW CREATE FUNCTION with no rights returns wrong error message.
--error ER_SP_DOES_NOT_EXIST
SHOW CREATE FUNCTION backup_test.f1;

--echo #
--echo # Checking privileges for a procedure.
--echo #
--error ER_PROCACCESS_DENIED_ERROR
DROP PROCEDURE backup_test.p1;
--error ER_PROCACCESS_DENIED_ERROR
ALTER PROCEDURE backup_test.p1 COMMENT "Tricky, eh?";
--error ER_DBACCESS_DENIED_ERROR
CREATE PROCEDURE backup_test.p1(p1 CHAR(20))
  INSERT INTO backup_test.t1 VALUES ("100");
# Note: SHOW CREATE PROCEDURE with no rights returns wrong error message.
--error ER_SP_DOES_NOT_EXIST
SHOW CREATE PROCEDURE backup_test.p1;

--echo #
--echo # Checking to make sure we cannot create a new or drop the
--echo # existing database.
--echo #
--error ER_DBACCESS_DENIED_ERROR
DROP DATABASE backup_test;
--error ER_DBACCESS_DENIED_ERROR
CREATE DATABASE x1;
--error ER_DBACCESS_DENIED_ERROR
ALTER DATABASE backup_test UPGRADE DATA DIRECTORY NAME;
