#
# This test is designed to ensure that the backup image file path name
# is handled like operating system would treat it.
#
# Needs the following variables:
# $WIN      1: Windows, 0: Not Windows
#
# Ingo Struewing, 2009-05-18
#

call mtr.add_suppression("Restore: Can't read backup location");

--echo #
--echo # Bug#43767 - Wrong path if backupdir is symlink and backref path used
--echo #

--echo # Select \$BACKUPDIR: \$MYSQLTEST_VARDIR/tmp
--let $BACKUPDIR = $MYSQLTEST_VARDIR/tmp

--echo # Select \$TESTDIR:   bup_image_path_dir
--let $TESTDIR = bup_image_path_dir

--echo # Preparatory cleanup.
--disable_warnings
--error 0,1
--remove_file $BACKUPDIR/$TESTDIR/bup_image_path_file.bak
--error 0,1,2
--rmdir $BACKUPDIR/$TESTDIR/dir1
--error 0,1,2
--rmdir $BACKUPDIR/$TESTDIR
DROP DATABASE IF EXISTS bup_image_path;
--enable_warnings

--echo # Create database.
CREATE DATABASE bup_image_path;
--echo # Create test directory \$BACKUPDIR/\$TESTDIR
--mkdir $BACKUPDIR/$TESTDIR
--echo # Create a subdirectory \$BACKUPDIR/\$TESTDIR/dir1
--mkdir $BACKUPDIR/$TESTDIR/dir1
--echo # Set backupdir variable (statement suppressed).
--disable_query_log
eval SET @@global.backupdir = '$BACKUPDIR';
--enable_query_log

--echo # Run BACKUP. Create new backup image file.
--replace_column 1 #
eval BACKUP DATABASE bup_image_path TO '$TESTDIR/bup_image_path_file.bak';

if (!$WIN)
{
  --echo # Attempt RESTORE through a non-sense path name.
  --replace_regex /Errcode: [0-9]+/Errcode: #/
  --replace_result $BACKUPDIR BACKUPDIR
  --error 29
  eval RESTORE FROM
    '$TESTDIR/non-existent-file.txt/../bup_image_path_file.bak'
    OVERWRITE;
}
if ($WIN)
{
  --echo # Run RESTORE through a non-sense path name.
  --replace_column 1 #
  eval RESTORE FROM
    '$TESTDIR/non-existent-file.txt/../bup_image_path_file.bak'
    OVERWRITE;
}

--echo # Run RESTORE through a valid path name.
# Replace backup_id and warning numbers
--replace_column 1 # 2 #
eval RESTORE FROM '$TESTDIR/bup_image_path_file.bak' OVERWRITE;

--echo # Run RESTORE through a valid path name.
# Replace backup_id and warning numbers
--replace_column 1 # 2 #
eval RESTORE FROM '$TESTDIR/./dir1/.././bup_image_path_file.bak' OVERWRITE;

--echo # Cleanup
--remove_file $BACKUPDIR/$TESTDIR/bup_image_path_file.bak
DROP DATABASE bup_image_path;
--rmdir $BACKUPDIR/$TESTDIR/dir1
--rmdir $BACKUPDIR/$TESTDIR
SET @@global.backupdir = DEFAULT;

