#
# Test cross-platform (xpfm) compatibility of backup images.
#
# Part 2 - Restore and test backup images from multiple platforms
#
# Needs variables:
#
#   $ENGINE_3                   storage engine for more tables
#   $ENGINE_3_USES_TABLESPACE   storage engine uses tablespaces
#   $SHOW_OBJECTS               path to include file that shows objects
#   $IMAGE_FILE                 backup image file name to restore
#
# WL#4771 - Online Backup: Test cross-platform compatibility
#
# Ingo Struewing, 2009-06-03
#
#
--disable_warnings
DROP DATABASE IF EXISTS bup_xpfm_compat_db1;
DROP DATABASE IF EXISTS BUP_XPFM_COMPAT_DB2;
DROP DATABASE IF EXISTS BupXPfmCompat_db3;
--enable_warnings
#
--echo #
--echo # Check setting of lower_case_table_names.
--echo #
SELECT @@lower_case_table_names;
#
--echo #
--echo # Set character set for table contents.
--echo #
SET NAMES 'utf8';
#
--echo #
--echo # Create users. Required to exist by RESTORE.
--echo #
CREATE USER 'bup_user1'@'%';
CREATE USER 'BUP_USER2';
CREATE USER 'BupUser3'@'%';
CREATE USER 'no_user'@'%';
#
--echo #
--echo # Set backupdir = '\$MYSQL_TEST_DIR/suite/backup/std_data'
--echo #
--disable_query_log
eval SET GLOBAL backupdir = '$MYSQL_TEST_DIR/suite/backup/std_data';
--enable_query_log
#
--echo #
--echo # Restore.
--echo #
--replace_column 1 #
eval RESTORE FROM '$IMAGE_FILE' OVERWRITE;
#
--echo #
--echo # Check object existence.
--echo #
--source $SHOW_OBJECTS
#
--echo #
--echo # Check table contents.
--echo #
SELECT COUNT(*) FROM bup_xpfm_compat_db1.table1;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM bup_xpfm_compat_db1.table1;
SELECT COUNT(*) FROM bup_xpfm_compat_db1.TABLE2;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM bup_xpfm_compat_db1.TABLE2;
SELECT COUNT(*) FROM bup_xpfm_compat_db1.TaBle3;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM bup_xpfm_compat_db1.TaBle3;
#
SELECT COUNT(*) FROM BUP_XPFM_COMPAT_DB2.table1;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BUP_XPFM_COMPAT_DB2.table1;
SELECT COUNT(*) FROM BUP_XPFM_COMPAT_DB2.TABLE2;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BUP_XPFM_COMPAT_DB2.TABLE2;
SELECT COUNT(*) FROM BUP_XPFM_COMPAT_DB2.TaBle3;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BUP_XPFM_COMPAT_DB2.TaBle3;
#
SELECT COUNT(*) FROM BupXPfmCompat_db3.table1;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BupXPfmCompat_db3.table1;
SELECT COUNT(*) FROM BupXPfmCompat_db3.TABLE2;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BupXPfmCompat_db3.TABLE2;
SELECT COUNT(*) FROM BupXPfmCompat_db3.TaBle3;
SELECT crn, c13, SUBSTR(c48 FROM 1 FOR 30) FROM BupXPfmCompat_db3.TaBle3;
#
--echo #
--echo # Execute views.
--echo #
SELECT c1, SUBSTR(c2 FROM 1 FOR 30), c3, c4 FROM bup_xpfm_compat_db1.view1;
SELECT SUBSTR(c2 FROM 1 FOR 30), c3 FROM bup_xpfm_compat_db1.VIEW2;
SELECT c3, c4 FROM bup_xpfm_compat_db1.ViEw3;
SELECT c2, c3 FROM BUP_XPFM_COMPAT_DB2.view1;
SELECT c1, SUBSTR(c2 FROM 1 FOR 30) FROM BUP_XPFM_COMPAT_DB2.VIEW2;
SELECT c3 FROM BUP_XPFM_COMPAT_DB2.ViEw3;
SELECT c1, c2 FROM BupXPfmCompat_db3.view1;
SELECT c1, c2 FROM BupXPfmCompat_db3.VIEW2;
SELECT c1, c2 FROM BupXPfmCompat_db3.ViEw3;
#
--echo #
--echo # Execute procedures. They insert their name into c48.
--echo #
CALL bup_xpfm_compat_db1.proc1;
CALL bup_xpfm_compat_db1.PROC2;
CALL bup_xpfm_compat_db1.PrOc3;
CALL BUP_XPFM_COMPAT_DB2.proc1;
CALL BUP_XPFM_COMPAT_DB2.PROC2;
CALL BUP_XPFM_COMPAT_DB2.PrOc3;
CALL BupXPfmCompat_db3.proc1;
CALL BupXPfmCompat_db3.PROC2;
CALL BupXPfmCompat_db3.PrOc3;
#
SELECT c48 FROM bup_xpfm_compat_db1.table1;
SELECT c48 FROM bup_xpfm_compat_db1.TABLE2;
SELECT c48 FROM bup_xpfm_compat_db1.TaBle3;
SELECT c48 FROM BUP_XPFM_COMPAT_DB2.table1;
SELECT c48 FROM BUP_XPFM_COMPAT_DB2.TABLE2;
SELECT c48 FROM BUP_XPFM_COMPAT_DB2.TaBle3;
SELECT c48 FROM BupXPfmCompat_db3.table1;
SELECT c48 FROM BupXPfmCompat_db3.TABLE2;
SELECT c48 FROM BupXPfmCompat_db3.TaBle3;
#
--echo #
--echo # Execute functions. They multiply their arg by 11, 12, 13, ..., 32, 33.
--echo # When Bug#9051 (Stored Functions: Database name in fully qualified name
--echo # is case sensitive) is fixed, the --error directives and the
--echo # secondary call of the functions in bup_xpfm_compat_db2 and
--echo # bupxpfmcompat_db3 shall be removed.
--echo #
SELECT bup_xpfm_compat_db1.func1(2);
SELECT bup_xpfm_compat_db1.FUNC2(3);
SELECT bup_xpfm_compat_db1.FuNc3(4);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BUP_XPFM_COMPAT_DB2.func1(5);
SELECT bup_xpfm_compat_db2.func1(5);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BUP_XPFM_COMPAT_DB2.FUNC2(6);
SELECT bup_xpfm_compat_db2.FUNC2(6);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BUP_XPFM_COMPAT_DB2.FuNc3(7);
SELECT bup_xpfm_compat_db2.FuNc3(7);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BupXPfmCompat_db3.func1(8);
SELECT bupxpfmcompat_db3.func1(8);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BupXPfmCompat_db3.FUNC2(9);
SELECT bupxpfmcompat_db3.FUNC2(9);
--error 0,ER_SP_DOES_NOT_EXIST
SELECT BupXPfmCompat_db3.FuNc3(10);
SELECT bupxpfmcompat_db3.FuNc3(10);
#
--echo #
--echo # Execute triggers.
--echo # Triggers 1 and 2 delete same row from tables 2 and 1 respectively.
--echo # Trigger 3 inserts 51, 52, 53 into table 3 of next db respectively. 
--echo #
INSERT INTO bup_xpfm_compat_db1.table1 SET c13=43 -- del 43 of TABLE2 (no-op);
INSERT INTO bup_xpfm_compat_db1.TABLE2 SET c13=43 -- del 43 of table1 (ok);
INSERT INTO bup_xpfm_compat_db1.TaBle3 SET c13=43 -- ins 51 in DB2.TABLE2;
INSERT INTO bup_xpfm_compat_db1.TABLE2 SET c13=44 -- del 44 of table1 (no-op);
INSERT INTO bup_xpfm_compat_db1.table1 SET c13=44 -- del 44 of TABLE2 (ok);
#
INSERT INTO BUP_XPFM_COMPAT_DB2.table1 SET c13=43 -- del 43 of TABLE2 (no-op);
INSERT INTO BUP_XPFM_COMPAT_DB2.TABLE2 SET c13=43 -- del 43 of table1 (ok);
INSERT INTO BUP_XPFM_COMPAT_DB2.TaBle3 SET c13=43 -- ins 52 in db3.TaBle3;
INSERT INTO BUP_XPFM_COMPAT_DB2.TABLE2 SET c13=44 -- del 44 of table1 (no-op);
INSERT INTO BUP_XPFM_COMPAT_DB2.table1 SET c13=44 -- del 44 of TABLE2 (ok);
#
INSERT INTO BupXPfmCompat_db3.table1 SET c13=43 -- del 43 of TABLE2 (no-op);
INSERT INTO BupXPfmCompat_db3.TABLE2 SET c13=43 -- del 43 of table1 (ok);
INSERT INTO BupXPfmCompat_db3.TaBle3 SET c13=43 -- ins 53 in db1.table1;
INSERT INTO BupXPfmCompat_db3.TABLE2 SET c13=44 -- del 44 of table1 (no-op);
INSERT INTO BupXPfmCompat_db3.table1 SET c13=44 -- del 44 of TABLE2 (ok);
#
SELECT c13 FROM bup_xpfm_compat_db1.table1 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM bup_xpfm_compat_db1.TABLE2 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM bup_xpfm_compat_db1.TaBle3 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BUP_XPFM_COMPAT_DB2.table1 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BUP_XPFM_COMPAT_DB2.TABLE2 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BUP_XPFM_COMPAT_DB2.TaBle3 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BupXPfmCompat_db3.table1 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BupXPfmCompat_db3.TABLE2 WHERE c13 BETWEEN 1 AND 100;
SELECT c13 FROM BupXPfmCompat_db3.TaBle3 WHERE c13 BETWEEN 1 AND 100;
#
--echo #
--echo # Cleanup.
--echo #
SET GLOBAL backupdir = DEFAULT;
DROP DATABASE bup_xpfm_compat_db1;
DROP DATABASE BUP_XPFM_COMPAT_DB2;
DROP DATABASE BupXPfmCompat_db3;
if ($ENGINE_3_USES_TABLESPACE)
{
  eval DROP TABLESPACE bup_xpfm_compat_ts1 ENGINE=$ENGINE_3;
  eval DROP TABLESPACE BUP_XPFM_COMPAT_TS2 ENGINE=$ENGINE_3;
  eval DROP TABLESPACE BupXPfmCompat_ts3 ENGINE=$ENGINE_3;
}
DROP USER 'bup_user1'@'%';
DROP USER 'BUP_USER2';
DROP USER 'BupUser3'@'%';
DROP USER 'no_user'@'%';

