# This include file creates databases and objects. This file will be used by
# rpl_backup_extra.test, rpl_backup_ptr.test, rpl_backup_multi.test
# This inc file will help avoid creating objects repeatedly in the tests 
# mentioned above

--echo # Create databases and objects

CREATE DATABASE db1;
CREATE DATABASE db2;
CREATE TABLE db1.t11(a INT NOT NULL AUTO_INCREMENT, b VARCHAR(100), c INT NOT NULL, PRIMARY KEY(a));
CREATE TABLE db1.t12(details CHAR(30));
CREATE TABLE db2.t21(id INT, fname VARCHAR(20), INDEX name(fname));

INSERT INTO db1.t11(b, c) VALUES('a',10),('b',20),('c',30),('d',40);
SELECT * FROM db1.t11;

CREATE VIEW db1.v1 AS SELECT * FROM db2.t21;

CREATE EVENT db2.e1 ON SCHEDULE EVERY 1 YEAR DISABLE DO
 DELETE FROM db1.t11 WHERE c > 100;

DELIMITER ||;

CREATE PROCEDURE db2.p1()
BEGIN
 SELECT * FROM db1.t12;
END;||

CREATE TRIGGER db2.trgi AFTER INSERT ON db2.t21 FOR EACH ROW
BEGIN
 INSERT INTO db1.t12 VALUES('trigger trg1 fired');
END;||

--echo Function will return number of times trigger & event is fired
CREATE FUNCTION db1.f1() RETURNS INT
 RETURN (SELECT COUNT(*) FROM db1.t12);||

--echo
--echo ### Create procedure to check objects in all databases ###

CREATE PROCEDURE test.show_objects(db CHAR(10))
BEGIN
SELECT TABLE_NAME, TABLE_TYPE FROM information_schema.tables
    WHERE TABLE_SCHEMA = db;
(SELECT routine_name , routine_type FROM information_schema.routines
    WHERE routine_schema = db)
UNION (SELECT event_name, 'EVENT' FROM information_schema.events
    WHERE event_schema = db)
UNION (SELECT trigger_name, 'TRIGGER' FROM information_schema.triggers
    WHERE trigger_schema = db) ORDER BY routine_name, routine_type;
END;||

DELIMITER ;||

--echo # Exercise objects
INSERT INTO db2.t21 VALUES(100, 'a');
SELECT * FROM db1.v1;
CALL db2.p1();
SELECT db1.f1();
SELECT COUNT(*) FROM db1.t11;

