/* Copyright (C) 2000-2002, 2004-2005 MySQL AB, 2008-2009 Sun Microsystems, Inc

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; version 2 of the License.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

/**
  @file
  Static variables for MyISAM library.
  All defined here for easy making of a shared library
*/

#ifndef _global_h
#include "myisamdef.h"
#endif

LIST	*myisam_open_list=0;
uchar	NEAR myisam_file_magic[]=
{ (uchar) 254, (uchar) 254,'\007', '\001', };
uchar	NEAR myisam_pack_file_magic[]=
{ (uchar) 254, (uchar) 254,'\010', '\002', };
char *myisam_logical_log_filename= (char*)"myisam.log";
IO_CACHE myisam_physical_log; /**< Physical log (used by online backup) */
IO_CACHE myisam_logical_log;  /**< Logical log (used for debugging) */
uint	myisam_quick_table_bits=9;
ulong	myisam_block_size= MI_KEY_BLOCK_LENGTH;		/* Best by test */
my_bool myisam_flush=0, myisam_delay_key_write=0, myisam_single_user=0;
#if defined(THREAD) && !defined(DONT_USE_RW_LOCKS)
uint myisam_concurrent_insert= 2;
#else
uint myisam_concurrent_insert= 0;
#endif
ulonglong myisam_max_temp_length= MAX_FILE_SIZE;
ulong    myisam_bulk_insert_tree_size=8192*1024;
ulong    myisam_data_pointer_size=4;
ulonglong    myisam_mmap_size= SIZE_T_MAX, myisam_mmap_used= 0;

static int always_valid(const char *filename __attribute__((unused)))
{
  return 0;
}

int (*myisam_test_invalid_symlink)(const char *filename)= always_valid;


/*
  read_vec[] is used for converting between P_READ_KEY.. and SEARCH_
  Position is , == , >= , <= , > , <
*/

uint NEAR myisam_read_vec[]=
{
  SEARCH_FIND, SEARCH_FIND | SEARCH_BIGGER, SEARCH_FIND | SEARCH_SMALLER,
  SEARCH_NO_FIND | SEARCH_BIGGER, SEARCH_NO_FIND | SEARCH_SMALLER,
  SEARCH_FIND | SEARCH_PREFIX, SEARCH_LAST, SEARCH_LAST | SEARCH_SMALLER,
  MBR_CONTAIN, MBR_INTERSECT, MBR_WITHIN, MBR_DISJOINT, MBR_EQUAL
};

uint NEAR myisam_readnext_vec[]=
{
  SEARCH_BIGGER, SEARCH_BIGGER, SEARCH_SMALLER, SEARCH_BIGGER, SEARCH_SMALLER,
  SEARCH_BIGGER, SEARCH_SMALLER, SEARCH_SMALLER
};

#ifdef HAVE_PSI_INTERFACE
PSI_mutex_key mi_key_mutex_MYISAM_SHARE_intern_lock,
  mi_key_mutex_MI_SORT_INFO_mutex, mi_key_mutex_HA_CHECK_print_msg;

static PSI_mutex_info all_myisam_mutexes[]=
{
  { &mi_key_mutex_MI_SORT_INFO_mutex, "MI_SORT_INFO::mutex", 0},
  { &mi_key_mutex_MYISAM_SHARE_intern_lock, "MYISAM_SHARE::intern_lock", 0},
  { &mi_key_mutex_HA_CHECK_print_msg, "HA_CHECK::print_msg", 0}
};

PSI_rwlock_key mi_key_rwlock_MYISAM_SHARE_key_root_lock,
  mi_key_rwlock_MYISAM_SHARE_mmap_lock;

static PSI_rwlock_info all_myisam_rwlocks[]=
{
  { &mi_key_rwlock_MYISAM_SHARE_key_root_lock, "MYISAM_SHARE::key_root_lock", 0},
  { &mi_key_rwlock_MYISAM_SHARE_mmap_lock, "MYISAM_SHARE::mmap_lock", 0}
};

PSI_cond_key mi_key_cond_MI_SORT_INFO_cond;

static PSI_cond_info all_myisam_conds[]=
{
  { &mi_key_cond_MI_SORT_INFO_cond, "MI_SORT_INFO::cond", 0}
};

PSI_file_key mi_key_file_datatmp, mi_key_file_dfile, mi_key_file_kfile,
  mi_key_file_log, mi_key_file_backuplog;

static PSI_file_info all_myisam_files[]=
{
  { &mi_key_file_datatmp, "data_tmp", 0},
  { &mi_key_file_dfile, "dfile", 0},
  { &mi_key_file_kfile, "kfile", 0},
  { &mi_key_file_log, "log", 0},
  { &mi_key_file_backuplog, "backuplog", 0}
};

PSI_thread_key mi_key_thread_find_all_keys, mi_key_thread_backup;

static PSI_thread_info all_myisam_threads[]=
{
  { &mi_key_thread_find_all_keys, "find_all_keys", 0},
  { &mi_key_thread_backup, "backup", 0}
};

void init_myisam_psi_keys()
{
  const char* category= "myisam";
  int count;

  if (PSI_server == NULL)
    return;

  count= array_elements(all_myisam_mutexes);
  PSI_server->register_mutex(category, all_myisam_mutexes, count);

  count= array_elements(all_myisam_rwlocks);
  PSI_server->register_rwlock(category, all_myisam_rwlocks, count);

  count= array_elements(all_myisam_conds);
  PSI_server->register_cond(category, all_myisam_conds, count);

  count= array_elements(all_myisam_files);
  PSI_server->register_file(category, all_myisam_files, count);

  count= array_elements(all_myisam_threads);
  PSI_server->register_thread(category, all_myisam_threads, count);
}
#endif /* HAVE_PSI_INTERFACE */


/** Hash of all tables for which we want physical logging */
const HASH *mi_log_tables_physical;
/**
  If page changes to the index file should be logged to the physical log.

  @note Changes to the header of the index file of a table in physical
  logging are always logged because the header is not redundant with the data
  file.
*/
my_bool mi_log_index_pages_physical;

/**
  All MyISAM-specific error messages which may be sent to the user.
  They will be localized (translated) as part of
  http://forge.mysql.com/worklog/task.php?id=2940
  "MySQL plugin interface: error reporting".
  Same order as enum myisam_errors.
*/
const char *myisam_error_messages[] =
{
  "online backup impossible with --external-locking",
  "backup archive format has too recent version (%u) (current: %u)"
};

static inline void myisam_error_messages_dummy_validator()
{
  compile_time_assert((sizeof(myisam_error_messages) /
                       sizeof(myisam_error_messages[0])) ==
                      (-MYISAM_ERR_LAST-1));
}
