/** @file

  Write and read backup image triggering errors during low-level write/read
  calls.
*/

#include <tap.h>

#include "stream_test.h"
#include "catalog.h"

image_header  img_header;


void run_test()
{
  int i;
  int  can_pass;
  
  /*
    Number of tests to be planned are not known at this point.
  */
  plan(NO_PLAN);

  init_catalog(&img_header);

  diag("Testing writing of backup image");

  reset_io_counts();
  ok(!write_image(&img_header, "io_errors.bst") && !check_iterators(),
     "Counting i/o write calls");

  diag("Made %lu write calls", io_counts.write);
  diag("Wrote %lu bytes", (long unsigned)io_counts.write_bytes);


  /*
    Errors during last 2 write calls (which happen during closing of a stream)
    are not reported by bstream library
  */
  can_pass= 2;

  for(i= io_counts.write; i > 0 ; --i)
  {
    reset_io_counts();
    io_counts.write= -i;
    ok((write_image(&img_header, "write_fail.bst") && !check_iterators())
       || can_pass, "Failing %d-th write call", i);

    reset_io_counts();
    ok((read_image(&img_header, "write_fail.bst") && !check_iterators())
       || can_pass, "Reading resulting image");
  
    if (can_pass)
      --can_pass;
  }

  diag("Testing reading of backup image");

  reset_io_counts();
  ok(!read_image(&img_header, "io_errors.bst") && !check_iterators(),
     "Counting i/o read calls");

  diag("Made %lu read calls", io_counts.read);
  diag("Read %lu bytes", (long unsigned)io_counts.read_bytes);


  for(i= io_counts.read; i > 0 ; --i)
  {
    reset_io_counts();
    io_counts.read= -i;
    ok(read_image(&img_header, "io_errors.bst") && !check_iterators(),
       "Failing %d-th read call", i);
  }

}
