#ifndef CATALOG_H_
#define CATALOG_H_

#include "stream_test.h"

extern const uint snap_count;
extern const uint global_count;
extern const uint db_count;
extern const uint table_count;
extern const uint perdb_count;
extern const uint pertable_count;

extern snapshot_type snapshots[];
extern item_info     objects_global[];
extern db_info       dbs[];
extern table_info    tables[];
extern item_info     objects_perdb[];
extern item_info     objects_pertable[];

/** 
  If non zero, makes the catalogue empty - no objects are reported by the 
  iterators. 
*/
extern int opt_empty_catalog;

/**
  Structure containing bstream callback counters.

  Whenever one of the callback functions is called, the corresponding
  counter will be increased.

  Setting counter to a negative value will cause the corresponding function
  report ERROR when counter reaches value of 0.
*/
extern struct st_callback_counts {
  int iterator_get[128];
  int iterator_free[128];
  int db_iterator_get[128];
  int db_iterator_free[128];
  int get_serialization[128];
  int get_metadata[128];
  int add_item[128];
  int create_item[128];
  int cat_reset;
  int cat_close;
  int alloc;
  int free;
} callback_counts;

/**
  Increase counter C, execute X if counter reaches value of 0.
*/
#define STEP_AND_CHECK_COUNT(C,X)   if (0 == ++(C)) X

void init_catalog(image_header*);
void reset_counts();
int  check_iterators();

#endif /*CATALOG_H_*/
